﻿<%@ Page Language="C#" %>

<!DOCTYPE html>

<script runat="server">
    public string Lang { get; set; }
    public string DdlPlaceholderText { get; set; }

    protected void Page_Load(object sender, System.EventArgs e)
    {
        Lang = "tr-TR";
        if (!string.IsNullOrEmpty(Request["lang"])) Lang = Request["lang"];

        switch (Lang)
        {
            case "en-US":
                DdlPlaceholderText = "Select Company";
                break;
            default:
                DdlPlaceholderText = "Firma Seçiniz";
                break;
        }

        var companies = Endeks.Service.GetCompanies();

        ddlCompanies.Items.Add(new ListItem(DdlPlaceholderText,""));

        foreach (var company in companies)
        {
            ddlCompanies.Items.Add(new ListItem(company.CompanyName, company.ID + ""));
        }

    }

</script>

<html xmlns="http://www.w3.org/1999/xhtml">
<head runat="server">
    <title></title>
    <link type="text/css" href="inc/styles.min.css" rel="stylesheet" />
    <style type="text/css">
        .chart-wrapper {
            width: 100%;
            max-height: 600px;
            min-height: 300px;
        }

        #ddlCompanies {
            border-radius: 0;
        }

        #chart {
            border-radius: 0;
            margin-bottom: 30px;
            padding: 20px;
        }

        .tooltip {
            margin-left: 10px;
        }
    </style>
</head>
<body>
    <form id="form1" runat="server">
        <div>
            <div class="form-group">
                
            <asp:DropDownList ID="ddlCompanies" runat="server" CssClass="form-control"></asp:DropDownList>
            </div>
            
            <div id="chart" class="chart-wrapper thumbnail" style="display: none;">
            </div>
            <div>
                <table id="chartdata" class="table table-hover" style="display: none;">
                    <thead>
                        <tr>
                            <th>Dönem</th>
                            <th>Not</th>
                            <th>Derecelendirme Firması</th>
                            <th>Rapor</th>
                        </tr>
                    </thead>
                    <tbody>
                    </tbody>
                </table>
            </div>
        </div>
    </form>
    <script type="text/javascript" src="inc/js/jquery-1.11.1.min.js"></script>
    <script type="text/javascript" src="inc/js/jquery-migrate-1.2.1.min.js"></script>
    <script type="text/javascript" src="inc/bootstrap/js/bootstrap.min.js"></script>
    <script type="text/javascript" src="inc/js/plugins/Chart.min.js"></script>
    <script type="text/javascript" src="inc/js/globalize/globalize.min.js"></script>
    <script type="text/javascript" src="inc/js/globalize/cultures/globalize.culture.<%=Lang%>.min.js"></script>

    <script type="text/javascript">
        var $$ = window.parent.$;

        Globalize.culture('<%=Lang%>');


        $(function () {
            var $companies = $("#ddlCompanies").on("change", function (e) {
                var $this = $(this);

                if ($this.val() != "") {
                    loadChart($this.val());
                }

            });

            resizeParentIframe();
            loadChart($companies.val());
        });

        $(window).on("resize", function () {
            renderChart($("#chart").data("cdata"));
            resizeParentIframe();
        });

        function loadChart(cid) {
            if (cid == "") return;

            var $chart = $("#chart");

            $chart.html('Yükleniyor...');
            $chart.data("edata", null);
            $chart.data("cdata", null);

            if ($$) {
                $$('html, body').animate({
                    scrollTop: $$("#endex").offset().top - 120
                }, 1000);
            }

            $.ajax({
                url: "EndeksApi.ashx?cmd=getcompanynotes&id=" + cid + "&lang=<%=Lang%>",
                success: function (data) {
                    var chartData = notesToChartData(data);

                    $chart.data("cdata", chartData);
                    $chart.data("edata", data);

                    renderChart(chartData);
                    renderDataTable(data);
                    resizeParentIframe();
                }
            });
        }


        function notesToChartData(note) {
            var data = {
                labels: [],
                datasets: [
                    {
                        fillColor: "rgba(96,156,236,.4)",
                        strokeColor: "rgba(96,156,236,.8)",
                        pointColor: "rgba(96,156,236,.8)",
                        pointStrokeColor: "#fff",
                        pointHighlightFill: "#fff",
                        pointHighlightStroke: "rgba(96,156,236,1)",
                        data: []
                    }
                ]
            };


            $.each(note, function (ix, item) {
                data.labels.push(Globalize.format(Globalize.parseDate(item.GradeDate), "MMM yyyy"));
                data.datasets[0].data.push(item.Grade);
            });

            return data;
        }

        function renderChart(data) {
            var $container = $("#chart");
            $container.html('<canvas></canvas>');

            var $chart = $container.find("canvas");

            var ctx = $chart.get(0).getContext("2d");

            $chart.attr('width', $container.width()); //max width
            $chart.attr('height', $container.height()); //max height                   

            new Chart(ctx).Line(data, {
                bezierCurve: false
            });

            $container.show();
        }

        function renderDataTable(data) {
            var dt = data.reverse();

            var $tbody = $("#chartdata tbody");

            $tbody.find("tr").remove();

            $.each(dt, function (ix, item) {
                if (item.Grade == 0) return;

                var $row = $('<tr>' +
                    '<td>' + Globalize.format(Globalize.parseDate(item.GradeDate), "MMMM yyyy") + '</td>' +
                    '<td>' + Globalize.format(item.Grade, "N2") + '</td>' +
                    '<td>' + item.RatingCompany + '</td>' +
                    '<td>&nbsp;</td>' +
                    '</tr>');

                if (item.FilePath != "") {
                    $row.find("td:last").html('<a href="' + item.FilePath + '" data-toggle="tooltip" data-placement="left" title="Raporu indirmek için tıklayınız" target="_blank"><i class="fa fa-file-pdf-o"></i></a>');
                }

                if (item.Description != "") {
                    $row.find("td:first").append('<i class="fa fa-question-circle tooltip" data-toggle="tooltip" data-placement="right" title="' + item.Description + '"></i>');
                }

                $row.find('[data-toggle="tooltip"]').tooltip();

                $tbody.append($row);
                $tbody.parent().show();
            });

        }

        function resizeParentIframe() {
            if ($$) {
                $$("#endex").height($("#form1").outerHeight(true));
            }
        }

        var item = {
            RatingID: 315,
            RatingCompany: "ISS",
            Grade: 89.45,
            GradeDate: "2014-03-01T00:00:00",
            FilePath: "",
            FileTitle: "",
            Description: "SPK’nın 01.02.2013 tarih ve 4/105 sayılı toplantısında alınan kararlar uyarınca, şirketlerin 2013 yılı kurumsal yönetim derecelendirme notları belirlenen prensipler çerçevesinde yenilenmiştir. "
        }

    </script>
</body>
</html>
